/*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
// (C) PicoPeta Simputers Pvt. Ltd. (2003)
// Author: Santhosh N

#include "theme.h"
#include "image.h"
#include "display.h"

#include <stdlib.h>
#include <string.h>

px_theme* themeptr = NULL;

px_theme* theme_get_theme()
{
	if (themeptr == NULL)
		themeptr = theme_create();

	return themeptr;
}

px_theme* theme_create()
{
	px_theme* ptr = (px_theme*)malloc(sizeof(px_theme));
	int count;
	
	ptr->theme_path = strdup(PREFIX"/settings/picowidget/themes/default/");

	for (count = 0; count < NR_THEME_PIXMAPS; count++)
		ptr->pixmaps[count] = NULL;

	ptr->load_theme = theme_load_theme;
	ptr->get_pixmap = theme_get_pixmap;
	ptr->destroy = theme_destroy;

	return ptr;
}

void theme_load_theme(px_theme* theme, const char* path)
{
}

px_pixmap* theme_get_pixmap (px_theme* theme, theme_pixmaps pix)
{
	if (theme->pixmaps[pix] == NULL)
	{
		char pixname[100];
		pixname[0] = '\0';
		
		switch (pix)
		{
			case SCROLLBAR_UP :
				strcpy(pixname, "scrollbar_up");
				break;

			case SCROLLBAR_DOWN:
				strcpy(pixname, "scrollbar_down");
				break;

			case SCROLLBAR_UP_ACTIVE :
				strcpy(pixname, "scrollbar_up_active");
				break;

			case SCROLLBAR_DOWN_ACTIVE:
				strcpy(pixname, "scrollbar_down_active");
				break;

			case SCROLLBAR_SLIDER:
				strcpy(pixname, "scrollbar_slider");
				break;

			case SCROLLBAR_TROUGH:
				strcpy(pixname, "scrollbar_trough");
				break;

			case SCROLLBAR_TROUGH2:
				strcpy(pixname, "scrollbar_trough");
				break;

			case SCROLLBAR_NOTCH:
				strcpy(pixname, "scrollbar_notch");
				break;

			case VSCROLLBAR_UP :
				strcpy(pixname, "vscrollbar_up");
				break;

			case VSCROLLBAR_DOWN:
				strcpy(pixname, "vscrollbar_down");
				break;

			case VSCROLLBAR_UP_ACTIVE :
				strcpy(pixname, "vscrollbar_up_active");
				break;

			case VSCROLLBAR_DOWN_ACTIVE:
				strcpy(pixname, "vscrollbar_down_active");
				break;

			case VSCROLLBAR_SLIDER:
				strcpy(pixname, "vscrollbar_slider");
				break;

			case VSCROLLBAR_TROUGH:
				strcpy(pixname, "vscrollbar_trough");
				break;

			case VSCROLLBAR_NOTCH:
				strcpy(pixname, "vscrollbar_notch");
				break;

			case HSCROLLBAR_LEFT :
				strcpy(pixname, "hscrollbar_left");
				break;

			case HSCROLLBAR_RIGHT:
				strcpy(pixname, "hscrollbar_right");
				break;

			case HSCROLLBAR_LEFT_ACTIVE :
				strcpy(pixname, "hscrollbar_left_active");
				break;

			case HSCROLLBAR_RIGHT_ACTIVE:
				strcpy(pixname, "hscrollbar_right_active");
				break;

			case HSCROLLBAR_SLIDER:
				strcpy(pixname, "hscrollbar_slider");
				break;

			case HSCROLLBAR_TROUGH:
				strcpy(pixname, "hscrollbar_trough");
				break;

			case HSCROLLBAR_NOTCH:
				strcpy(pixname, "hscrollbar_notch");
				break;

			case CHECKBUTTON_ON:
				strcpy(pixname, "checkbutton_on");
				break;

			case CHECKBUTTON_OFF:
				strcpy(pixname, "checkbutton_off");
				break;

			case RADIOBUTTON_ON:
				strcpy(pixname, "radiobutton_on");
				break;

			case RADIOBUTTON_OFF:
				strcpy(pixname, "radiobutton_off");
				break;

			case VBACK_SLIDER:
			    strcpy(pixname, "vback_slider");
			    break;

			case VFORE_SLIDER:
			    strcpy(pixname, "vfore_slider");
			    break;

			case HBACK_SLIDER:
			    strcpy(pixname, "hback_slider");
			    break;

			case HFORE_SLIDER:
					strcpy(pixname, "hfore_slider");
					break;

			case STIPPLE12:
				strcpy(pixname, "gray12.bmp");
				break;
						
			case STIPPLE25:
				strcpy(pixname, "gray25.bmp");
				break;
				
			case STIPPLE50:
				strcpy(pixname, "gray50.bmp");
				break;
				
			case STIPPLE75:
				strcpy(pixname, "gray75.bmp");
				break;

			case TABIMAGE:
			  strcpy(pixname, "tabimage");
			  break;

			case TABIMAGE_ACTIVE:
			  strcpy(pixname, "tabimage_active");
			  break;

			case COMBOBOX_DOWN:
			  strcpy(pixname, "combobox_down");
			  break;

			case COMBOBOX_DOWN_ACTIVE:
			  strcpy(pixname, "combobox_down_active");
			  break;

			default:
				break;
		}

		if (pixname[0] != '\0')
		{
			char* path = (char*)malloc(sizeof(char) * (strlen(theme->theme_path) + strlen(pixname) + 1));
			Display* display = display_get_Xdisplay();
			strcpy(path, theme->theme_path);
			strcat(path, pixname);
		
			theme->pixmaps[pix] = (px_pixmap*)malloc(sizeof(px_pixmap));

			image_initialize_pixmap(theme->pixmaps[pix]);
			
			if (pix == STIPPLE12 || pix == STIPPLE25 || pix == STIPPLE50 || pix == STIPPLE75)
			{
				px_display* display = get_display();
		
				image_create_pixmap(DefaultRootWindow(display->display), theme->pixmaps[pix], 16, 16);
				XReadBitmapFile(display->display, DefaultRootWindow(display->display), 
						 path, &(theme->pixmaps[pix]->w), &(theme->pixmaps[pix]->h), 
						 &(theme->pixmaps[pix]->pxmp), NULL, NULL);
			}
			else
				image_load_file(DefaultRootWindow(display), theme->pixmaps[pix], path);
			free(path);
		}
	}

	return theme->pixmaps[pix];
}

void theme_destroy(px_theme* theme)
{
	int count;
	
	if (theme->theme_path != NULL)
		free(theme->theme_path);

	for (count = 0; count < NR_THEME_PIXMAPS; count++)
		if (theme->pixmaps[count] != NULL)
		{
			image_destroy(theme->pixmaps[count]);
			free(theme->pixmaps[count]);
		}

}



